@@ -2,8 +2,8 @@ from typing import overload
 from typing import List
 from typing import TypeVar
 from typing import Mapping
-from .EditorScreen import *
-from .AutoCompleteSuggestion import *
+from .EditorScreen import EditorScreen
+from .AutoCompleteSuggestion import AutoCompleteSuggestion
 
 Runnable = TypeVar["java.lang.Runnable"]
 
