@@ -1,8 +1,8 @@
 from typing import overload
 from typing import TypeVar
-from .Button import *
+from .Button import Button
 
-Consumer = TypeVar["java.util.function.Consumer_xyz.wagyourtail.jsmacros.client.gui.elements.Button_"]
+Consumer = TypeVar["java.util.function.Consumer_xyz.wagyourtail.wagyourgui.elements.Button_"]
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
 Text = TypeVar["net.minecraft.text.Text"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
