@@ -1,5 +1,5 @@
 from typing import overload
-from .BaseProfile import *
+from .BaseProfile import BaseProfile
 
 
 class BaseEvent:
