@@ -1,5 +1,5 @@
 from typing import overload
-from .BaseWrappedException_SourceLocation import *
+from .BaseWrappedException_SourceLocation import BaseWrappedException_SourceLocation
 
 
 class BaseWrappedException_HostLocation(BaseWrappedException_SourceLocation):
