@@ -2,14 +2,12 @@ from typing import overload
 from typing import List
 from typing import TypeVar
 from typing import Mapping
-from .ICategoryTreeParent import *
-from .MultiElementContainer import *
-from .Scrollbar import *
-from .CategoryTreeContainer import *
-from .Button import *
+from .ICategoryTreeParent import ICategoryTreeParent
+from .MultiElementContainer import MultiElementContainer
+from .Scrollbar import Scrollbar
+from .Button import Button
 
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
-Map = TypeVar["java.util.Map_java.lang.String,xyz.wagyourtail.jsmacros.client.gui.settings.CategoryTreeContainer_"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
 
 class CategoryTreeContainer(ICategoryTreeParent, MultiElementContainer):
