@@ -2,11 +2,9 @@ from typing import overload
 from typing import List
 from typing import TypeVar
 from typing import Mapping
-from .Sorting_MacroSortMethod import *
+from .Sorting_MacroSortMethod import Sorting_MacroSortMethod
 
 JsonObject = TypeVar["com.google.gson.JsonObject"]
-List = TypeVar["java.util.List_java.lang.String_"]
-Map = TypeVar["java.util.Map_java.lang.String,short[]_"]
 Comparator = TypeVar["java.util.Comparator_xyz.wagyourtail.jsmacros.core.config.ScriptTrigger_"]
 
 class ClientConfigV2:
@@ -17,6 +15,8 @@ class ClientConfigV2:
 	editorHistorySize: int
 	editorSuggestions: bool
 	editorFont: str
+	externalEditor: bool
+	externalEditorCommand: str
 
 	@overload
 	def __init__(self) -> None:
