@@ -1,11 +1,12 @@
 from typing import overload
 from typing import TypeVar
+from .BaseEvent import BaseEvent
 from .BaseHelper import BaseHelper
 
-CommandContext = TypeVar["com.mojang.brigadier.context.CommandContext_net.fabricmc.fabric.api.client.command.v1.FabricClientCommandSource_"]
+CommandContext = TypeVar["com.mojang.brigadier.context.CommandContext__"]
 StringRange = TypeVar["com.mojang.brigadier.context.StringRange"]
 
-class CommandContextHelper(BaseHelper):
+class CommandContextHelper(BaseEvent, BaseHelper):
 	"""
 	Since: 1.4.2 
 	"""
