@@ -4,7 +4,7 @@ from typing import Mapping
 
 T = TypeVar("T")
 JsonObject = TypeVar["com.google.gson.JsonObject"]
-Logger = TypeVar["org.apache.logging.log4j.Logger"]
+Logger = TypeVar["org.slf4j.Logger"]
 File = TypeVar["java.io.File"]
 
 class ConfigManager:
