@@ -3,6 +3,7 @@ from typing import List
 from typing import TypeVar
 from .Draw3D_Box import Draw3D_Box
 from .Draw3D_Line import Draw3D_Line
+from .Draw3D_Surface import Draw3D_Surface
 from .PositionCommon_Pos3D import PositionCommon_Pos3D
 
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
@@ -30,6 +31,13 @@ class Draw3D:
 		"""
 		pass
 
+	@overload
+	def getDraw2Ds(self) -> List[Draw3D_Surface]:
+		"""
+		Since: 1.6.5 
+		"""
+		pass
+
 	@overload
 	def addBox(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, fillColor: int, fill: bool) -> Draw3D_Box:
 		"""
@@ -242,6 +250,147 @@ class Draw3D:
 		"""
 		pass
 
+	@overload
+	def addDraw2D(self, x: float, y: float, z: float) -> Draw3D_Surface:
+		"""
+		Since: 1.6.5 
+
+		Args:
+			x: top left 
+			y: 
+			z: 
+		"""
+		pass
+
+	@overload
+	def addDraw2D(self, x: float, y: float, z: float, width: float, height: float) -> Draw3D_Surface:
+		"""
+		Since: 1.6.5 
+
+		Args:
+			x: 
+			width: 
+			y: 
+			z: 
+			height: 
+		"""
+		pass
+
+	@overload
+	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float) -> Draw3D_Surface:
+		"""
+		Since: 1.6.5 
+
+		Args:
+			zRot: 
+			yRot: 
+			x: 
+			xRot: 
+			y: 
+			z: 
+		"""
+		pass
+
+	@overload
+	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float) -> Draw3D_Surface:
+		"""
+		Since: 1.6.5 
+
+		Args:
+			zRot: 
+			yRot: 
+			x: 
+			xRot: 
+			width: 
+			y: 
+			z: 
+			height: 
+		"""
+		pass
+
+	@overload
+	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float, minSubdivisions: int) -> Draw3D_Surface:
+		"""
+		Since: 1.6.5 
+
+		Args:
+			zRot: 
+			yRot: 
+			x: 
+			xRot: 
+			width: 
+			y: 
+			z: 
+			minSubdivisions: 
+			height: 
+		"""
+		pass
+
+	@overload
+	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float, minSubdivisions: int, renderBack: bool) -> Draw3D_Surface:
+		"""
+		Since: 1.6.5 
+
+		Args:
+			zRot: 
+			yRot: 
+			x: 
+			xRot: 
+			width: 
+			y: 
+			z: 
+			minSubdivisions: 
+			renderBack: 
+			height: 
+		"""
+		pass
+
+	@overload
+	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float, minSubdivisions: int, renderBack: bool, cull: bool) -> Draw3D_Surface:
+		"""
+		Since: 1.6.5 
+
+		Args:
+			zRot: 
+			yRot: 
+			x: top left 
+			xRot: 
+			width: 
+			y: 
+			z: 
+			minSubdivisions: 
+			renderBack: 
+			height: 
+		"""
+		pass
+
+	@overload
+	def removeDraw2D(self, surface: Draw3D_Surface) -> None:
+		"""
+		Since: 1.6.5 
+		"""
+		pass
+
+	@overload
+	def register(self) -> "Draw3D":
+		"""register so it actually shows up\n
+		Since: 1.6.5 
+
+		Returns:
+			self for chaining 
+		"""
+		pass
+
+	@overload
+	def unregister(self) -> "Draw3D":
+		"""
+		Since: 1.6.5 
+
+		Returns:
+			self for chaining 
+		"""
+		pass
+
 	@overload
 	def render(self, matrixStack: MatrixStack) -> None:
 		pass
