@@ -1,8 +1,11 @@
 from typing import overload
-from .BaseEvent import *
+from .BaseEvent import BaseEvent
 
 
 class EventChunkLoad(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	x: int
 	z: int
 	isFull: bool
