@@ -1,8 +1,11 @@
 from typing import overload
-from .BaseEvent import *
+from .BaseEvent import BaseEvent
 
 
 class EventDimensionChange(BaseEvent):
+	"""
+	Since: 1.2.7 
+	"""
 	dimension: str
 
 	@overload
