@@ -9,9 +9,12 @@ class EventEXPChange(BaseEvent):
 	progress: float
 	total: int
 	level: int
+	prevProgress: float
+	prevTotal: int
+	prevLevel: int
 
 	@overload
-	def __init__(self, progress: float, total: int, level: int) -> None:
+	def __init__(self, progress: float, total: int, level: int, prevProgress: float, prevTotal: int, prevLevel: int) -> None:
 		pass
 
 	@overload
