@@ -7,10 +7,11 @@ Entity = TypeVar["net.minecraft.entity.Entity"]
 
 class EventEntityDamaged(BaseEvent):
 	entity: EntityHelper
+	health: float
 	damage: float
 
 	@overload
-	def __init__(self, e: Entity, amount: float) -> None:
+	def __init__(self, e: Entity, health: float, amount: float) -> None:
 		pass
 
 	@overload
