@@ -5,9 +5,10 @@ from .TextHelper import TextHelper
 from .TextBuilder import TextBuilder
 from .CommandBuilder import CommandBuilder
 from .CommandNodeHelper import CommandNodeHelper
+from .CommandManager import CommandManager
 from .ChatHistoryManager import ChatHistoryManager
 
-Logger = TypeVar["org.apache.logging.log4j.Logger"]
+Logger = TypeVar["org.slf4j.Logger"]
 
 class FChat(BaseLibrary):
 	"""Functions for interacting with chat.
@@ -202,8 +203,18 @@ to close and/or the to wait for the sent message\n
 		"""
 		pass
 
+	@overload
+	def getCommandManager(self) -> CommandManager:
+		"""
+		Since: 1.7.0 
+		"""
+		pass
+
 	@overload
 	def getHistory(self) -> ChatHistoryManager:
+		"""
+		Since: 1.7.0 
+		"""
 		pass
 
 	@overload
