@@ -6,6 +6,7 @@ from .IDraw2D import IDraw2D
 from .Draw3D import Draw3D
 from .ScriptScreen import ScriptScreen
 from .IScreen import IScreen
+from .Draw2D import Draw2D
 
 
 class FHud(BaseLibrary):
@@ -76,12 +77,9 @@ An instance of this class is passed to scripts as the 'Hud' variable.\n
 		pass
 
 	@overload
-	def createDraw2D(self) -> IDraw2D:
+	def createDraw2D(self) -> Draw2D:
 		"""
 		Since: 1.0.5 
-
-		Returns:
-			a new IDraw2D . 
 		"""
 		pass
 
