@@ -1,6 +1,6 @@
 from typing import overload
 from typing import TypeVar
-from .Button import *
+from .Button import Button
 
 File = TypeVar["java.io.File"]
 
