@@ -1,12 +1,12 @@
 from typing import overload
-from typing import TypeVar
 from typing import Mapping
-from .HTTPRequest import *
-from .HTTPRequest_Response import *
+from .HTTPRequest_Response import HTTPRequest_Response
 
-Map = TypeVar["java.util.Map_java.lang.String,java.lang.String_"]
 
 class HTTPRequest:
+	"""
+	Since: 1.1.8 
+	"""
 	headers: Mapping[str, str]
 	conn: URL
 
@@ -16,14 +16,30 @@ class HTTPRequest:
 
 	@overload
 	def addHeader(self, key: str, value: str) -> "HTTPRequest":
+		"""
+		Since: 1.1.8 
+
+		Args:
+			value: 
+			key: 
+		"""
 		pass
 
 	@overload
 	def get(self) -> HTTPRequest_Response:
+		"""
+		Since: 1.1.8 
+		"""
 		pass
 
 	@overload
 	def post(self, data: str) -> HTTPRequest_Response:
+		"""
+		Since: 1.1.8 
+
+		Args:
+			data: 
+		"""
 		pass
 
 	pass
