@@ -365,6 +365,53 @@ class IDraw2D:
 		"""
 		pass
 
+	@overload
+	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
+		"""
+		Since: 1.6.5 
+
+		Args:
+			color: 
+			imageY: 
+			textureWidth: 
+			imageX: 
+			rotation: 
+			regionWidth: 
+			textureHeight: 
+			x: 
+			width: 
+			y: 
+			regionHeight: 
+			id: 
+			height: 
+			zIndex: 
+		"""
+		pass
+
+	@overload
+	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, alpha: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
+		"""
+		Since: 1.6.5 
+
+		Args:
+			color: 
+			imageY: 
+			textureWidth: 
+			imageX: 
+			rotation: 
+			regionWidth: 
+			textureHeight: 
+			alpha: 
+			x: 
+			width: 
+			y: 
+			regionHeight: 
+			id: 
+			height: 
+			zIndex: 
+		"""
+		pass
+
 	@overload
 	def removeImage(self, i: RenderCommon_Image) -> T:
 		"""
@@ -708,6 +755,11 @@ class IDraw2D:
 
 	@overload
 	def render(self, matrixStack: MatrixStack) -> None:
+		"""internal
+
+		Args:
+			matrixStack: 
+		"""
 		pass
 
 	pass
