@@ -1,7 +1,7 @@
 from typing import overload
 from typing import TypeVar
-from .EntityHelper import *
-from .ItemStackHelper import *
+from .EntityHelper import EntityHelper
+from .ItemStackHelper import ItemStackHelper
 
 ItemEntity = TypeVar["net.minecraft.entity.ItemEntity"]
 
