@@ -9,7 +9,7 @@ Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
 MinecraftClient = TypeVar["net.minecraft.client.MinecraftClient"]
 InputUtil_Key = TypeVar["net.minecraft.client.util.InputUtil.Key"]
 Text = TypeVar["net.minecraft.text.Text"]
-Logger = TypeVar["org.apache.logging.log4j.Logger"]
+Logger = TypeVar["org.slf4j.Logger"]
 
 class JsMacros:
 	MOD_ID: str
@@ -58,10 +58,6 @@ class JsMacros:
 	def range(self, start: int, end: int, iter: int) -> List[int]:
 		pass
 
-	@overload
-	def tryAutoCastNumber(self, returnType: Class, number: object) -> object:
-		pass
-
 	pass
 
 
