@@ -1,13 +1,11 @@
 from typing import overload
-from typing import TypeVar
 from typing import Mapping
-from .Library import *
-from .BaseLibrary import *
-from .PerLanguageLibrary import *
-from .BaseLanguage import *
-from .ContextContainer import *
+from .Library import Library
+from .BaseLibrary import BaseLibrary
+from .PerLanguageLibrary import PerLanguageLibrary
+from .BaseLanguage import BaseLanguage
+from .BaseScriptContext import BaseScriptContext
 
-Map = TypeVar["java.util.Map_java.lang.String,xyz.wagyourtail.jsmacros.core.library.BaseLibrary_"]
 
 class LibraryRegistry:
 	libraries: Mapping[Library, BaseLibrary]
@@ -20,7 +18,7 @@ class LibraryRegistry:
 		pass
 
 	@overload
-	def getLibraries(self, language: BaseLanguage, context: ContextContainer) -> Mapping[str, BaseLibrary]:
+	def getLibraries(self, language: BaseLanguage, context: BaseScriptContext) -> Mapping[str, BaseLibrary]:
 		pass
 
 	@overload
@@ -28,7 +26,7 @@ class LibraryRegistry:
 		pass
 
 	@overload
-	def getPerExecLibraries(self, language: BaseLanguage, context: ContextContainer) -> Mapping[str, BaseLibrary]:
+	def getPerExecLibraries(self, language: BaseLanguage, context: BaseScriptContext) -> Mapping[str, BaseLibrary]:
 		pass
 
 	@overload
