@@ -1,12 +1,11 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
-from .MultiElementContainer import *
-from .IOverlayParent import *
+from .MultiElementContainer import MultiElementContainer
+from .IOverlayParent import IOverlayParent
 
 Consumer = TypeVar["java.util.function.Consumer_java.lang.Integer_"]
 MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
-List = TypeVar["java.util.List_net.minecraft.text.Text_"]
 Text = TypeVar["net.minecraft.text.Text"]
 TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]
 
