@@ -1,21 +1,26 @@
 from typing import overload
 from typing import List
 from typing import TypeVar
+from typing import Generic
 from .LivingEntityHelper import LivingEntityHelper
 from .TradeOfferHelper import TradeOfferHelper
 
-MerchantEntity = TypeVar["net.minecraft.entity.passive.MerchantEntity"]
+T = TypeVar("T")
 
-class MerchantEntityHelper(LivingEntityHelper):
+class MerchantEntityHelper(Generic[T], LivingEntityHelper):
 
 	@overload
-	def __init__(self, e: MerchantEntity) -> None:
+	def __init__(self, e: T) -> None:
 		pass
 
 	@overload
 	def getTrades(self) -> List[TradeOfferHelper]:
+		"""these might not work... depends on the data the server sends, maybe just singleplayer.
 		"""
-		"""
+		pass
+
+	@overload
+	def refreshTrades(self) -> List[TradeOfferHelper]:
 		pass
 
 	@overload
@@ -30,6 +35,10 @@ class MerchantEntityHelper(LivingEntityHelper):
 		"""
 		pass
 
+	@overload
+	def toString(self) -> str:
+		pass
+
 	pass
 
 
