@@ -1,9 +1,8 @@
 from typing import overload
-from typing import List
 from typing import TypeVar
-from .IFontManager import *
+from typing import Set
+from .IFontManager import IFontManager
 
-Set = TypeVar["java.util.Set_net.minecraft.util.Identifier_"]
 Identifier = TypeVar["net.minecraft.util.Identifier"]
 
 class MixinFontManager(IFontManager):
@@ -13,7 +12,7 @@ class MixinFontManager(IFontManager):
 		pass
 
 	@overload
-	def jsmacros_getFontList(self) -> List[Identifier]:
+	def jsmacros_getFontList(self) -> Set[Identifier]:
 		pass
 
 	pass
