@@ -1,7 +1,6 @@
 from typing import overload
 from typing import TypeVar
 
-DamageSource = TypeVar["net.minecraft.entity.damage.DamageSource"]
 CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]
 
 class MixinLivingEntity:
@@ -11,11 +10,11 @@ class MixinLivingEntity:
 		pass
 
 	@overload
-	def getHealth(self) -> float:
+	def getMaxHealth(self) -> float:
 		pass
 
 	@overload
-	def onDamage(self, source: DamageSource, amount: float, ci: CallbackInfo) -> None:
+	def onSetHealth(self, health: float, ci: CallbackInfo) -> None:
 		pass
 
 	pass
