@@ -1,5 +1,5 @@
 from typing import overload
-from .IMerchantScreen import *
+from .IMerchantScreen import IMerchantScreen
 
 
 class MixinMerchantScreen(IMerchantScreen):
