@@ -1,6 +1,6 @@
 from typing import overload
 from typing import TypeVar
-from .IRecipeBookWidget import *
+from .IRecipeBookWidget import IRecipeBookWidget
 
 RecipeBookResults = TypeVar["net.minecraft.client.gui.screen.recipebook.RecipeBookResults"]
 
