@@ -133,6 +133,23 @@ class MixinScreen(IScreen, AbstractParentElement):
 
 	@overload
 	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
+		"""
+		Since: 1.4.0 
+		"""
+		pass
+
+	@overload
+	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
+		"""
+		Since: 1.6.5 
+		"""
+		pass
+
+	@overload
+	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, alpha: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
+		"""
+		Since: 1.6.5 
+		"""
 		pass
 
 	@overload
@@ -244,7 +261,7 @@ class MixinScreen(IScreen, AbstractParentElement):
 		pass
 
 	@overload
-	def close(self) -> None:
+	def soft$close(self) -> None:
 		pass
 
 	@overload
