@@ -1,5 +1,5 @@
 from typing import overload
-from .ISignEditScreen import *
+from .ISignEditScreen import ISignEditScreen
 
 
 class MixinSignEditScreen(ISignEditScreen):
