@@ -107,12 +107,12 @@ class OptionsHelper(BaseHelper):
 		pass
 
 	@overload
-	def setFov(self, fov: float) -> "OptionsHelper":
+	def setFov(self, fov: int) -> "OptionsHelper":
 		"""
 		Since: 1.1.7 
 
 		Args:
-			fov: 
+			fov: (int since 1.7.0) 
 		"""
 		pass
 
