@@ -2,14 +2,14 @@ from typing import overload
 from typing import TypeVar
 from typing import Generic
 from .BaseLibrary import BaseLibrary
-from .BaseScriptContext import BaseScriptContext
 
 T = TypeVar("T")
+U = TypeVar("U")
 
-class PerExecLanguageLibrary(Generic[T], BaseLibrary):
+class PerExecLanguageLibrary(Generic[U, T], BaseLibrary):
 
 	@overload
-	def __init__(self, context: BaseScriptContext, language: Class) -> None:
+	def __init__(self, context: T, language: Class) -> None:
 		pass
 
 	pass
