@@ -56,14 +56,60 @@ class PositionCommon_Vec2D:
 	def getMagnitude(self) -> float:
 		pass
 
+	@overload
+	def getMagnitudeSq(self) -> float:
+		"""
+		Since: 1.6.5 
+
+		Returns:
+			magnitude squared 
+		"""
+		pass
+
 	@overload
 	def add(self, vec: "PositionCommon_Vec2D") -> "PositionCommon_Vec2D":
 		pass
 
+	@overload
+	def add(self, x1: float, y1: float, x2: float, y2: float) -> "PositionCommon_Vec2D":
+		"""
+		Since: 1.6.3 
+
+		Args:
+			y1: 
+			x1: 
+			y2: 
+			x2: 
+		"""
+		pass
+
 	@overload
 	def multiply(self, vec: "PositionCommon_Vec2D") -> "PositionCommon_Vec2D":
 		pass
 
+	@overload
+	def multiply(self, x1: float, y1: float, x2: float, y2: float) -> "PositionCommon_Vec2D":
+		"""
+		Since: 1.6.3 
+
+		Args:
+			y1: 
+			x1: 
+			y2: 
+			x2: 
+		"""
+		pass
+
+	@overload
+	def scale(self, scale: float) -> "PositionCommon_Vec2D":
+		"""
+		Since: 1.6.3 
+
+		Args:
+			scale: 
+		"""
+		pass
+
 	@overload
 	def dotProduct(self, vec: "PositionCommon_Vec2D") -> float:
 		pass
@@ -72,6 +118,16 @@ class PositionCommon_Vec2D:
 	def reverse(self) -> "PositionCommon_Vec2D":
 		pass
 
+	@overload
+	def normalize(self) -> "PositionCommon_Vec2D":
+		"""
+		Since: 1.6.5 
+
+		Returns:
+			a new Vec2D with the same direction but a magnitude of 1 
+		"""
+		pass
+
 	@overload
 	def toString(self) -> str:
 		pass
