@@ -2,6 +2,9 @@ from typing import overload
 
 
 class RenderCommon:
+	"""
+	Since: 1.2.3 
+	"""
 
 	@overload
 	def __init__(self) -> None:
