@@ -1,4 +1,5 @@
 from typing import overload
+from typing import List
 from typing import TypeVar
 from typing import Mapping
 from .BaseHelper import BaseHelper
@@ -24,6 +25,27 @@ class ScoreboardObjectiveHelper(BaseHelper):
 		"""
 		pass
 
+	@overload
+	def scoreToDisplayName(self) -> Mapping[int, TextHelper]:
+		"""
+		Since: 1.8.0 
+		"""
+		pass
+
+	@overload
+	def getKnownPlayers(self) -> List[str]:
+		"""
+		Since: 1.7.0 
+		"""
+		pass
+
+	@overload
+	def getKnownPlayersDisplayNames(self) -> List[TextHelper]:
+		"""
+		Since: 1.8.0 
+		"""
+		pass
+
 	@overload
 	def getName(self) -> str:
 		"""
