@@ -40,7 +40,7 @@ class ScriptScreen(BaseScreen):
 		pass
 
 	@overload
-	def onClose(self) -> None:
+	def close(self) -> None:
 		pass
 
 	pass
