@@ -1,6 +1,8 @@
 from typing import overload
+from typing import TypeVar
 from .ScriptTrigger_TriggerType import ScriptTrigger_TriggerType
 
+File = TypeVar["java.io.File"]
 
 class ScriptTrigger:
 	triggerType: ScriptTrigger_TriggerType
@@ -8,6 +10,10 @@ class ScriptTrigger:
 	scriptFile: str
 	enabled: bool
 
+	@overload
+	def __init__(self, triggerType: ScriptTrigger_TriggerType, event: str, scriptFile: File, enabled: bool) -> None:
+		pass
+
 	@overload
 	def __init__(self, triggerType: ScriptTrigger_TriggerType, event: str, scriptFile: str, enabled: bool) -> None:
 		pass
