@@ -1,6 +1,7 @@
 from typing import overload
 from typing import TypeVar
 from .BaseHelper import BaseHelper
+from .MethodWrapper import MethodWrapper
 
 Text = TypeVar["net.minecraft.text.Text"]
 
@@ -57,6 +58,26 @@ class TextHelper(BaseHelper):
 		"""
 		pass
 
+	@overload
+	def getStringStripFormatting(self) -> str:
+		"""
+		Since: 1.6.5 
+
+		Returns:
+			the text content. stripped formatting when servers send it the (super) old way due to shitty coders. 
+		"""
+		pass
+
+	@overload
+	def visit(self, visitor: MethodWrapper) -> None:
+		"""
+		Since: 1.6.5 
+
+		Args:
+			visitor: function with 2 args, no return. 
+		"""
+		pass
+
 	@overload
 	def toJson(self) -> str:
 		"""
