@@ -1,9 +1,12 @@
 from typing import overload
 from typing import TypeVar
 
+MinecraftClient = TypeVar["net.minecraft.client.MinecraftClient"]
+MultiplayerServerListPinger = TypeVar["net.minecraft.client.network.MultiplayerServerListPinger"]
 ItemStack = TypeVar["net.minecraft.item.ItemStack"]
 
 class TickBasedEvents:
+	serverListPinger: MultiplayerServerListPinger
 
 	@overload
 	def __init__(self) -> None:
@@ -22,7 +25,7 @@ class TickBasedEvents:
 		pass
 
 	@overload
-	def init(self) -> None:
+	def onTick(self, mc: MinecraftClient) -> None:
 		pass
 
 	pass
