@@ -4,35 +4,40 @@ from .EventContainer import EventContainer
 from .BaseEvent import BaseEvent
 from .EventFallFlying import EventFallFlying
 from .EventDisconnect import EventDisconnect
+from .EventInteractBlock import EventInteractBlock
 from .EventEXPChange import EventEXPChange
 from .EventCustom import EventCustom
 from .EventRecvMessage import EventRecvMessage
 from .EventHeal import EventHeal
+from .EventWrappedScript import EventWrappedScript
+from .EventInteractEntity import EventInteractEntity
 from .EventAirChange import EventAirChange
 from .EventBlockUpdate import EventBlockUpdate
 from .CodeCompileEvent import CodeCompileEvent
 from .EventEntityHealed import EventEntityHealed
 from .EventClickSlot import EventClickSlot
 from .EventResourcePackLoaded import EventResourcePackLoaded
-from .EventDimensionChange import EventDimensionChange
 from .EventItemDamage import EventItemDamage
+from .EventDimensionChange import EventDimensionChange
 from .EventJoinedTick import EventJoinedTick
 from .EventItemPickup import EventItemPickup
 from .EventOpenScreen import EventOpenScreen
-from .EventDeath import EventDeath
 from .EventTitle import EventTitle
+from .EventDeath import EventDeath
+from .EventAttackEntity import EventAttackEntity
 from .EventSignEdit import EventSignEdit
 from .CommandContextHelper import CommandContextHelper
 from .EventSendMessage import EventSendMessage
 from .EventTick import EventTick
 from .EventSound import EventSound
-from .EventOpenContainer import EventOpenContainer
 from .EventKey import EventKey
+from .EventOpenContainer import EventOpenContainer
 from .EventProfileLoad import EventProfileLoad
 from .EventBossbar import EventBossbar
+from .EventAttackBlock import EventAttackBlock
 from .EventService import EventService
-from .EventEntityLoad import EventEntityLoad
 from .EventDamage import EventDamage
+from .EventEntityLoad import EventEntityLoad
 from .EventPlayerLeave import EventPlayerLeave
 from .EventChunkLoad import EventChunkLoad
 from .EventChunkUnload import EventChunkUnload
@@ -41,8 +46,8 @@ from .EventDropSlot import EventDropSlot
 from .EventArmorChange import EventArmorChange
 from .EventRiding import EventRiding
 from .EventPlayerJoin import EventPlayerJoin
-from .EventEntityUnload import EventEntityUnload
 from .EventJoinServer import EventJoinServer
+from .EventEntityUnload import EventEntityUnload
 from .EventEntityDamaged import EventEntityDamaged
 from .EventHeldItemChange import EventHeldItemChange
 
