@@ -3,18 +3,18 @@ from typing import TypeVar
 from .EventContainer import EventContainer
 from .BaseEvent import BaseEvent
 from .FChat import FChat
-from .FWrapper import FWrapper
 from .FPlayer import FPlayer
 from .FRequest import FRequest
-from .FTime import FTime
 from .FKeyBind import FKeyBind
 from .FHud import FHud
-from .FJsMacros import FJsMacros
+from .FTime import FTime
 from .FFS import FFS
+from .FJsMacros import FJsMacros
 from .FReflection import FReflection
-from .FClient import FClient
 from .FWorld import FWorld
+from .FClient import FClient
 from .FGlobalVars import FGlobalVars
+from .IFWrapper import IFWrapper
 from .FPositionCommon import FPositionCommon
 
 File = TypeVar["java.io.File"]
@@ -22,18 +22,18 @@ File = TypeVar["java.io.File"]
 
 
 Chat = FChat()
-JavaWrapper = FWrapper()
 Player = FPlayer()
 Request = FRequest()
-Time = FTime()
 KeyBind = FKeyBind()
 Hud = FHud()
-JsMacros = FJsMacros()
+Time = FTime()
 FS = FFS()
+JsMacros = FJsMacros()
 Reflection = FReflection()
-Client = FClient()
 World = FWorld()
+Client = FClient()
 GlobalVars = FGlobalVars()
+JavaWrapper = IFWrapper()
 PositionCommon = FPositionCommon()
 context = EventContainer()
 file = File()
